================
Context Managers
================

.. automodule:: fabric.context_managers

    .. autofunction:: cd(path)
    .. autofunction:: hide(*groups)
    .. autofunction:: settings
    .. autofunction:: show(*groups)
